@@ -178,11 +178,11 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
     def _sort_algebraic_modules(self, max_iterations: int = 10_000) -> None:
         def submodule(v: AlgebraicModule) -> Dict[str, Set[str]]:
             return {
-                "in": set(v.compounds),
+                "in": set(v.args),
                 "out": set(v.derived_compounds),
             }
 
-        available_compounds = set(self.compounds)
+        available_compounds = set(self.compounds) | set(self.parameters) | {"time"}
         module_order = []
         modules_to_sort: SimpleQueue = SimpleQueue()
         for k, v in self.algebraic_modules.items():
