@@ -5,7 +5,7 @@ __all__ = [
 ]
 
 from abc import ABC, abstractmethod
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, Optional, Tuple, Union
 
 from ...typing import Array, ArrayLike
 
