@@ -4,7 +4,7 @@ __all__ = [
     "_IntegratorAssimulo",
 ]
 
-from typing import Any, Callable, Dict, List, Optional, Tuple
+from typing import Any, Callable, Dict, Optional, Tuple
 
 import numpy as np
 from assimulo.problem import Explicit_Problem  # type: ignore
