@@ -248,12 +248,13 @@ class Model(_AbstractRateModel, BaseModel):
     def _update_derived_stoichiometries(self) -> None:
         for rate_name, d in self.derived_stoichiometries.items():
             for cpd_name, stoichiometry in d.items():
-                self.stoichiometries[rate_name].update(
-                    {
-                        cpd_name: stoichiometry.function(
-                            *(self.parameters[i] for i in stoichiometry.args)
-                        )
-                    }
+                new_stoichiometry = stoichiometry.function(
+                    *(self.parameters[i] for i in stoichiometry.args)
+                )
+
+                self.stoichiometries.setdefault(rate_name, {}).update({cpd_name: new_stoichiometry})
+                self.stoichiometries_by_compounds.setdefault(cpd_name, {}).update(
+                    {rate_name: new_stoichiometry}
                 )
 
     def update_parameter(
